==> gs2-java-cdk-1.0.42-sources.jar: io/gs2/cdk/formation/ref/PropertyFormModelRef.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.formation.ref;

import io.gs2.cdk.core.func.GetAttr;
import io.gs2.cdk.core.func.Join;
import io.gs2.cdk.formation.stampSheet.AcquireActionsToPropertyFormProperties;
import io.gs2.cdk.core.model.AcquireAction;
import io.gs2.cdk.formation.model.AcquireActionConfig;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class PropertyFormModelRef {
    private String namespaceName;
    private String propertyFormModelName;

    public PropertyFormModelRef(
        String namespaceName,
        String propertyFormModelName
    ) {
        this.namespaceName = namespaceName;
        this.propertyFormModelName = propertyFormModelName;
    }

    public AcquireActionsToPropertyFormProperties acquireActionsToPropertyFormProperties(
        String propertyId,
        AcquireAction acquireAction,
        List<AcquireActionConfig> config,
        String userId
    ) {
        return (new AcquireActionsToPropertyFormProperties(
            this.namespaceName,
            this.propertyFormModelName,
            propertyId,
            acquireAction,
            config,
            userId
        ));
    }


    public AcquireActionsToPropertyFormProperties acquireActionsToPropertyFormProperties(
        String propertyId,
        AcquireAction acquireAction,
        List<AcquireActionConfig> config
    ) {
        return (new AcquireActionsToPropertyFormProperties(
            this.namespaceName,
            this.propertyFormModelName,
            propertyId,
            acquireAction,
            config,
            "#{userId}"
        ));
    }

    public String grn(
    ) {
        return (new Join(
            ":",
            Arrays.asList(
                "grn",
                "gs2",
                GetAttr.region(
                ).str(
                ),
                GetAttr.ownerId(
                ).str(
                ),
                "formation",
                this.namespaceName,
                "model",
                "propertyForm",
                this.propertyFormModelName
            )
        )).str(
        );
    }
}

==> gs2-java-cdk-1.0.58-sources.jar: io/gs2/cdk/formation/ref/PropertyFormModelRef.java <==
/*
 * Copyright 2016- Game Server Services, Inc. or its affiliates. All Rights
 * Reserved.
 *
 * Licensed under the Apache License, Version 2.0 (the "License").
 * You may not use this file except in compliance with the License.
 * A copy of the License is located at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * or in the "license" file accompanying this file. This file is distributed
 * on an "AS IS" BASIS, WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either
 * express or implied. See the License for the specific language governing
 * permissions and limitations under the License.
 */
package io.gs2.cdk.formation.ref;

import io.gs2.cdk.core.func.GetAttr;
import io.gs2.cdk.core.func.Join;
import io.gs2.cdk.formation.stampSheet.AcquireActionsToPropertyFormProperties;
import io.gs2.cdk.core.model.AcquireAction;
import io.gs2.cdk.core.model.Config;
import java.util.Arrays;
import java.util.List;
import java.util.stream.Collectors;

public class PropertyFormModelRef {
    private String namespaceName;
    private String propertyFormModelName;

    public PropertyFormModelRef(
        String namespaceName,
        String propertyFormModelName
    ) {
        this.namespaceName = namespaceName;
        this.propertyFormModelName = propertyFormModelName;
    }

    public AcquireActionsToPropertyFormProperties acquireActionsToPropertyFormProperties(
        String propertyId,
        AcquireAction acquireAction,
        List<Config> config,
        String userId
    ) {
        return (new AcquireActionsToPropertyFormProperties(
            this.namespaceName,
            this.propertyFormModelName,
            propertyId,
            acquireAction,
            config,
            userId
        ));
    }


    public AcquireActionsToPropertyFormProperties acquireActionsToPropertyFormProperties(
        String propertyId,
        AcquireAction acquireAction,
        List<Config> config
    ) {
        return (new AcquireActionsToPropertyFormProperties(
            this.namespaceName,
            this.propertyFormModelName,
            propertyId,
            acquireAction,
            config,
            "#{userId}"
        ));
    }

    public String grn(
    ) {
        return (new Join(
            ":",
            Arrays.asList(
                "grn",
                "gs2",
                GetAttr.region(
                ).str(
                ),
                GetAttr.ownerId(
                ).str(
                ),
                "formation",
                this.namespaceName,
                "model",
                "propertyForm",
                this.propertyFormModelName
            )
        )).str(
        );
    }
}
